package de.tudarmstadt.maki.simonstrator.api.component.sensor.location.location3D;

import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.LocationActuator;

/**
 * Interface for location actuators with energy consumption. Gives access to
 * actuator state control and sensors.
 * 
 * @author Julian Zobel
 *
 */
public interface EnergyConsumingLocationActuator extends LocationActuator {

	public boolean isAvailable();
	
	public boolean isActive();
	
	public boolean activate();
	
	public boolean deactivate();
	
	public boolean isMoving();
	
	public boolean setMoving();
	
	public boolean holdPosition();
	
	/**
	 * Energy calculation of this actuator based on a given distance. Calculates the
	 * energy needed in Joule when flying the given distance (with maximum available
	 * speed).
	 * 
	 * @param distance
	 *            Given distance that is used as calculation basis
	 * @return The energy in Joule, needed to fly the distance.
	 */
	public double energyCalculation(double distance);

}
