/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of Simonstrator.KOM.
 * 
 * Simonstrator.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package de.tudarmstadt.maki.simonstrator.api.component.sensor.location.location3D;

import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.Location;

/**
 * Extension of the {@link Location} interface to support 3D navigation and
 * movement.
 * 
 * @author Julian Zobel
 *
 */
public interface Location3D extends Location {

	/**
	 * Sets the content of the 3d location object to the specified 3d location
	 * 
	 * @param l
	 *            3D Location
	 */
	public void set(Location3D l);

	/**
	 * Sets the height in meters from the ground.
	 * 
	 * @param height
	 *            distance of this location object from the ground in meters
	 *
	 */
	public void setHeight(double height);

	/**
	 * Get the distance of the location object in meters
	 * 
	 * @return height in meters
	 */
	public double getHeight();

	/**
	 * Copy the current 3D location object.
	 * 
	 */
	public Location3D clone();

	/**
	 * Distance to the destination in meters. Uses the third dimension for
	 * calculation of height distances.
	 * 
	 */
	public double distanceTo(Location3D dest);
}
