/*
 *
 * This file is part of Simonstrator.KOM.
 * 
 * Simonstrator.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package de.tudarmstadt.maki.simonstrator.api.component.sensor.location.location3D;

import java.util.Set;

import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.AttractionPoint;

/**
 * Actuator for 3D location information, allowing to change a host's current
 * location.
 * 
 * @author Julian Zobel
 *
 */
public interface LocationActuator3D extends LocationSensor3D {

	/**
	 * Updates the node's current location with the new location. There is no
	 * guarantee that this operation will succeed. IF the current location
	 * changed, the {@link LocationSensor} will accurately reflect this.
	 * 
	 * @param newLocation
	 * 
	 */
	public void updateCurrentLocation(Location3D newLocation);

	/**
	 * A way to interact with node movement from within applications and the
	 * like. This is an optional operation - it is expected to throw an
	 * {@link UnsupportedOperationException} if it is not supported.
	 * 
	 * @param targetAttractionPoint
	 *            {@link AttractionPoint} the node should move to.
	 */
	public void setTargetAttractionPoint(AttractionPoint3D targetAttractionPoint) throws UnsupportedOperationException;

	/**
	 * Returns all currently known (to this node) attraction points. These can
	 * be used for example to update the target location.
	 * 
	 * @return
	 */
	public Set<AttractionPoint3D> getAllAttractionPoints();

	/**
	 * Programmatically add a new attraction point. This is an optional operation -
	 * it is expected to throw an {@link UnsupportedOperationException} if it is not
	 * supported.
	 * 
	 * @param attractionPoint
	 */
	public void addTargetAttractionPoint(AttractionPoint3D attractionPoint) throws UnsupportedOperationException;

	/**
	 * Programmatically remove an attraction point. This is an optional operation -
	 * it is expected to throw an {@link UnsupportedOperationException} if it is not
	 * supported.
	 * 
	 * @param toRemove
	 */
	default public void removeAttractionPoint(AttractionPoint3D toRemove) {
		throw new UnsupportedOperationException();
	}

}
