/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of Simonstrator.KOM.
 * 
 * Simonstrator.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package de.tudarmstadt.maki.simonstrator.api.component.sensor.location.location3D;

import de.tudarmstadt.maki.simonstrator.api.component.sensor.SensorComponent;
import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.AttractionPoint;
import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.LocationRequest;
import de.tudarmstadt.maki.simonstrator.api.component.sensor.location.LocationSensor;

/**
 * Extension of the {@link LocationSensor} to support 3D locations
 * 
 * @author Julian Zobel
 * 
 */
public interface LocationSensor3D extends SensorComponent {

	/**
	 * Retrieve the last known location
	 * 
	 * @return
	 */
	public Location3D getLastLocation();

	/**
	 * Start receiving location updates with the specified accuracy or interval
	 * on the provided listener. The listener fires as soon as possible with a
	 * valid location (in simulations: immediately) and from then on with the
	 * desired interval lengths.
	 * 
	 * @param request
	 *            (can be null - in this case, the listener will only be
	 *            notified if some other location requests exists and if a new
	 *            location is determined without active search by this specific
	 *            request)
	 * @param listener
	 */
	public void requestLocationUpdates(LocationRequest request,
			LocationListener3D listener);

	/**
	 * Get rid of location updates for the corresponding listener (and save
	 * energy)
	 * 
	 * @param listener
	 */
	public void removeLocationUpdates(LocationListener3D listener);

	/**
	 * Retrieve a {@link LocationRequest} object for manipulation and usage with
	 * requestLocationUpdates
	 * 
	 * @return
	 */
	public LocationRequest getLocationRequest();

	/**
	 * Retrieve the targeted {@link AttractionPoint}, representing the location
	 * the node is currently approaching.
	 * 
	 * @return
	 */
	public AttractionPoint3D getCurrentTargetAttractionPoint();

}
